From 27d53a9f98081cd8480217dc9eaf026c57c005f9 Mon Sep 17 00:00:00 2001
From: tomrink <rink@ssec.wisc.edu>
Date: Tue, 12 Jan 2021 21:12:47 -0600
Subject: [PATCH] snapshot...

---
 modules/aeolus/aeolus_amv.py | 34 +++++++++++++++++++++-------------
 1 file changed, 21 insertions(+), 13 deletions(-)

diff --git a/modules/aeolus/aeolus_amv.py b/modules/aeolus/aeolus_amv.py
index c10e5486..9dead440 100644
--- a/modules/aeolus/aeolus_amv.py
+++ b/modules/aeolus/aeolus_amv.py
@@ -55,26 +55,27 @@ def get_amvs(amv_files, timestamp, filepath=None):
     return param_nd
 
 
-# raob_dict: time -> profiles
-# amv_files_path: directory containing AMVs, '/home/user/amvdir/'
-# return dict: raob -> tuple (amv_lon, amv_lat, amv_pres, amv_spd, amv_dir)
-def match_amvs_to_raobs(raob_dict,  raob_time, amv_files, filepath=None):
-    nav = amv_files.get_navigation()
-    amv_params = amv_files.get_parameters()
+# raob_dict: (lat,lon) -> profiles
+# raob_time: nominal time
+# amv_ds: AMV data source
+# return dict: raob -> tuple (amv_lon, amv_lat, elem, line, amv_pres, amv_spd, amv_dir)
+def match_amvs_to_raobs(raob_dict, raob_time, amv_ds, filepath=None):
+    nav = amv_ds.get_navigation()
+    amv_params = amv_ds.get_parameters()
     match_dict = {}
 
     if filepath is None:
-        filepath, ftime, f_idx = amv_files.get_file(raob_time)
+        filepath, ftime, f_idx = amv_ds.get_file(raob_time)
 
     ds = Dataset(filepath)
 
-    amv_lons = ds[amv_files.lon_name][:].data
-    amv_lats = ds[amv_files.lat_name][:].data
-    if amv_files.elem_name is None or amv_files.line_name is None:
+    amv_lons = ds[amv_ds.lon_name][:].data
+    amv_lats = ds[amv_ds.lat_name][:].data
+    if amv_ds.elem_name is None or amv_ds.line_name is None:
         cc, ll = nav.earth_to_lc_s(amv_lons, amv_lats)
     else:
-        cc = ds[amv_files.elem_name][:].data
-        ll = ds[amv_files.line_name][:].data
+        cc = ds[amv_ds.elem_name][:].data
+        ll = ds[amv_ds.line_name][:].data
 
     param_s = []
     param_s.append(amv_lons)
@@ -95,6 +96,13 @@ def match_amvs_to_raobs(raob_dict,  raob_time, amv_files, filepath=None):
         else:
             param_s.append(data.data)
 
+    # filter
+    qc_name = amv_ds.get_qc_params()
+    if qc_name is not None:
+        qc_param = ds[qc_name][:].data
+        good = amv_ds.filter(qc_param)
+        vld = np.logical_and(vld, good)
+
     param_nd = np.vstack(param_s)
     param_nd = param_nd[:, vld]
     cc = param_nd[2, :]
@@ -1248,7 +1256,7 @@ def make_plot(bin_ranges, bin_values):
 
     #do_plot(x_values, [std_r, std_g, std], ['ICE', 'NOT ICE', 'ALL'], ['blue', 'red', 'black'], title='ACHA - RAOB ', x_axis_label='STD (hPa)', y_axis_label='hPa', invert=True, flip=True)
     #do_plot(x_values, [bias_r, bias_g, bias], ['ICE', 'NOT ICE', 'ALL'], ['blue', 'red', 'black'], title='ACHA - RAOB Pres Match', x_axis_label='BIAS (m/s)', y_axis_label='hPa', invert=True, flip=True)
-    do_plot(x_values, [bias_r, bias_g, bias], ['ICE', 'NOT ICE', 'ALL'], ['blue', 'red', 'black'], title='ACHA - GFS BestFit', x_axis_label='BIAS (m/s)', y_axis_label='hPa', invert=True, flip=True)
+    do_plot(x_values, [mad_r, mad_g, mad], ['ICE', 'NOT ICE', 'ALL'], ['blue', 'red', 'black'], title='ACHA - GFS BestFit (ALL)', x_axis_label='MAD (hPa)', y_axis_label='hPa', invert=True, flip=True)
     #do_plot(x_values, [mad_r, mad_g, mad], ['ICE', 'NOT ICE', 'ALL'], ['blue', 'red', 'black'], title='ACHA - RAOB Pres Match', x_axis_label='MAD (m/s)', y_axis_label='hPa', invert=True, flip=True)
     #do_plot(x_values, [num_vals_r, num_vals_g, num_vals], ['ICE: '+str(num_r), 'NOT ICE: '+str(num_g), 'ALL: '+str(num)], ['blue', 'red', 'black'], title='ACHA - RAOB BestFit', x_axis_label='log(Count)', y_axis_label='hPa', invert=True, flip=True)
 
-- 
GitLab